#
# spec file for package 7kaa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_version 2.15
Name:           7kaa
Version:        %{base_version}.6
Release:        1.6
Summary:        Seven Kingdoms: Ancient Adversaries
License:        GPL-2.0-only
Group:          Amusements/Games/Strategy/Real Time
URL:            https://7kfans.com/
Source0:        https://github.com/the3dfxdude/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.png
Source2:        %{name}.desktop
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  curl-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2) >= 2.24.0
Recommends:     %{name}-music >= %{base_version}

%description
Seven Kingdoms made departures from the traditional real-time strategy models
of "gather resources, build a base and army, and attack". The economic model
bears more resemblance to a turn-based strategy game. It features an espionage
system that allows players to train and control spies individually, who each
have a spying skill that increases over time. The player is also responsible
for catching spies in their own kingdom. Inns built within the game allow
players to hire mercenaries of various occupations, skill levels, and races.
Skilled spies of enemy races are essential to a well-conducted espionage
program, and the player can bolster his forces by grabbing a skilled fighter
or give ones own factories, mines, and towers of science, a boost by hiring a
skilled professional.

Enlight Software decided to release the game to the Open Source community
in August 2009. At that time everything, but the music, was released under
the GPL v2.

%prep
%setup -q

%build
autoreconf -if
./autogen.sh
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%configure --docdir=%{_docdir}/%{name}
%make_build

%install
%make_install

# install icon
install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/%{name}.png

# install Desktop file
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}
%find_lang %{name}

# remove duplicate COPYING file
rm -f %{buildroot}%{_docdir}/7kaa/COPYING

%files -f %{name}.lang
%license COPYING
%doc README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}

%changelog
* Tue Sep 26 2023 Dirk Stoecker <opensuse@dstoecker.de>
- switch build to official release file
* Sat Sep 23 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.15.6
  * Fixed bugs related to rebelling
  * Improved AI on handling rebellions
  * Fixed several crash bugs
  * Fixed small graphic update bugs
  * Fixed bug when assigning to ship
  * Fixed AI declare war bug
  * Fixed AI give tribute bug
  * Greatly improved AI sea based missions
  * Improved AI on training and recruiting
  * Cleaned up some deinit code
  * Improved handling of town migration with workers
  * Improved AI to be move aggressive in attack missions
  * Improved validation of attack actions
  * Added display of the land mass size in the F10 menu
  * Enabled town peasant migration
  * Created button for markets to control stocking type
  * Added Phoenix vision on fryhtan lairs
  * Improved AI at building harbors
  * Fixed bugs related to AI surrenders
  * Improved locale code
  * Made English the default language on Windows
  * Increased the max number of raw resource sites to 10
  * Fixed bug on trade ship docking and exiting
  * Reduced penalty on trade unit destruction
  * Improved distance calculating so placing buildings and towns
    on any side is treated the same
  * Fixed some path finding issues
  * Enabled the ability for AI to scout the map
  * Fixed screen edge mouse handling bug
  * Fixed exploit when spying on an enemy nation report
  * Improved AI handling on granting money to towns and recruiting
  * Increased the speed of speed level 9
- Update BuildRequires pkgconfig(sdl2) >= 2.24.0
* Sun May  1 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.15.5
  * Added Esperanto translation
  * Added a credits screen
  * Added support for copying trade routes for trade ships
  * Added a copy trade route button when hovering the mouse over
    units in the trade report
  * Added a request builder button when a building is selected
  * Improved stability of starting a multiplayer game
  * Improved AI's handling of combat mission at sea
  * Improved formatting of the game manual
  * Improved idle-attack detection when there are many units in the game
  * Improved the AI's ability to send help to an ally
  * Improved Fryhtan AI to help an Ordo under attack
  * Reduced load of crc checking in multiplayer
  * Reset powered attack type when line-of-sight is broken
  * Do not cycle powered attack when the target moves,
    correcting the usage behavior of Egyptian fire arrows
  * More trade report improvements
  * Set the default for mobilizing civilians to non-aggressive mode
    to prevent inadvertently sending them to their death
  * Corrected building linkage when buildings are densely placed
  * Corrected AI related bugs
  * Fixed wrongly applied leadership gain when the leader was not in range
  * Fixed more crashes
  * Fixed UI regression in setting auto taxing
  * Fixed incorrect pathing when unit is in a building or on a ship
  * Fixed crashes related to bullets
  * Fixed spy vision of a spy on a ship
  * Fixed spy vision of a spy assigned to building for construction or repair
- Drop upstream resolved patches
  * gcc6_char_cast.patch
  * 7kaa-no-return-in-nonvoid-function.patch
* Tue Apr 27 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed music version requirement (align with music package)
* Sun Jul 12 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.15.4p1
  * This is a patch release to fix a few issues with 2.15.4.
    All users should upgrade.
- Update to 2.15.4
  * Fixed a problem in multiplayer that halted the game play.
  * Added option to play with the original seven kingdoms, and
    enabled on original scenarios.
  * Apply the leadership bonus when the general is in fort for
    defending soldiers in range.
  * Fixed the mobile general range calculation for the leadership
    bonus to not apply to the troop anywhere on the map.
  * Apply the leadership bonus when the general is on a ship for
    defending soldiers in range.
  * Updated translations.
  * Added hotkeys for managing the build menu in the War Factory,
    Harbor, and Town.
  * Restored support for real full screen resolution that requires
    a screen mode change.
  * Improved dynamic UI button and text layout.
  * Added Polish translation.
  * Added trade locations to the trade report.
  * Sort and filter trade locations based on the map selected
    caravan.
  * Allow setting stops using the trade report.
  * Allow copying trade routes using the trade report.
- Add 7kaa-no-return-in-nonvoid-function.patch
- Clean with spec-cleaner
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.15.3. Changes since 2.15.2:
  * Fixed corrupt characters and fields in various in game messages.
  * Improved translation support.
  * Updated translations.
  * Added some UI improvements.
  * Fixed some crashing issues related to spies.
  * Standardized on FPU code generation for better cross-platform
    compatibility.
  * Added more advanced config options.
  * Improved manual.
  * Added key binding support.
  * Prevented chat keystrokes registering as a hotkey too.
  * Fixed sometimes hiring wrong unit in the inn.
  * Added scenario advanced config presets to restore default
    scenario game play to original game design parameters.
  * Ensure screen redraw when dropping spy identity.
  * Improved alternate font set.
  * Added scroll button for long tutor messages.
  * Removed gong sound for unsent AI diplomatic messages.
  * Re-enabled AI ability to request direct military aid;
    expect allied AI to work together on defending now.
  * Removed uninitialized parameter in Caravan CRC check.
  * Removed improper variable-size cast, causing incorrect
    action processing on 64-bit platforms.
  * Correct replay initialization for weather sync.
* Tue Feb 19 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to 2.15.1
  * Fixed desync on mobilizing workers.
  * Fixed desync on troop sortie, by making troop sorting deterministic.
  * Fixed desync on AI attack planning, by making AI fort sorting deterministic.
  * Fixed error that caused multiplayer save files appear out of sync.
  * Changed the Button class to not block on holding down the mouse button,
    smoothing multiplayer games when alot of clicking may be happening.
  * Prevent mobilizing foreign workers from your Firms, however they may be
    fired back to their home town.
  * Only enable mobilize worker button when the firm is staffed with non-foreign
    workers.
  * Prefer IPv4 addressing for 7kfans.com match-making.
  * Fixed ambiguity in some translations.
  * Repack structures for Crc checking due to pointer sizing.
  * Improved cross-compilation and platform support.
  * Uppercased the data and user files, as they are supported in the code,
    maintaining consistency and without needing to guess case.
  * Fixed missing Fryhtan encyclopedia picture on some systems.
  * Fixed observation mode visibility when playing a replay.
  * Added support for center and right paragraph justification.
  * Packagers please note that the music files must be in upper-case now, see
    the latest download for the music.
- Clean with spec-cleaner
- Make sure we recommend new 7kaa-music version
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to 2.14.7
  * improving usability of the 7K multiplayer service at 7kfans.com
  * added NAT punch-through support when using 7kfans.com, which will
  make online play easier and more reliable.
  * Game balancing changes and fixes, making the game more challenging
  + The Fryhtans can attack more often.
  + Spies are more stealthy.
  + Greater being mana exploit has been fixed.
  + Harder to brutally capture towns.
- File under correct Group
- Lint .spec file
- Rebase gcc6_char_cast.patch
* Mon Sep  5 2016 nemysis@openSUSE.org
- Update to 2.14.6, announce message:
  * Added support for 7kfans.com match-making.
  * Added LAN game browsing support.
  * Added Mobilize Worker button on firms. (sraboy/Microvirus)
  * Improvements to mouse acceleration.
  * Fixes to mouse movement in fullscreen mode.
  * Fixed a bug with 64-bit multiplayer matches.
  * Begun translation work. (toaster)
  * Fix character encoding with accented characters. (MicroVirus)
  * Bugfixes…
- Remove obsolete patches 7kaa-2.14.5.patch and 7kaa-2.14.5_overflow.patch,
  changed by Upstream
- Add description for patch gcc6_char_cast.patch
- Remove check %%if 0%%{?suse_version}, because is only for openSUSE
* Thu Jun 16 2016 normand@linux.vnet.ibm.com
- new gcc6_char_cast.patch proposal for upstream issue
  https://github.com/the3dfxdude/7kaa/issues/63
* Tue Sep 29 2015 opensuse@dstoecker.de
- patch buffer overflow (7kaa-2.14.5_overflow.patch)
* Fri Sep 25 2015 nemysis@openSUSE.org
- Update to 2.14.5, announce message:
  * Switched to using SDL2.
  * Gained support for full-screen stretching.
  * Gained support for MacOS.
  * Switched to using enet, replacing SDL_net.
  * Audio code improvements.
  * The multiplayer connection code has stablized.
  * New game hotkeys.
  * Migrate population across extended town networks.
  * Added ability to migrate 10 people at a time across between towns.
  * Gettext translation support.
  * Several bug fixes.
- Add patch 7kaa-2.14.5.patch, - fix build
- Remove BuildRequires for desktop-file-utils
- Add BuildRequires, changed by Upstream for enet-devel and sdl2
- Remove BuildRequires, changed by Upstream for SDL_net and sdl
- Fix build with gcc5, add CXXFLAGS="%%{optflags} -fno-strict-aliasing"
* Fri Nov  7 2014 nemysis@gmx.ch
- Use for Recommends:%%{name}-music Recommends: instead of
  Requires:%%{name}-music, with dimstar help
* Tue Oct 14 2014 nemysis@gmx.ch
- Change Web URL
* Mon Oct 13 2014 nemysis@gmx.ch
- Binary file '7kaa-source-2.14.4.tar.bz2' has changed.
* Mon Oct 13 2014 nemysis@gmx.ch
- Change Source0 to use proper Web URL
- Use check for openSUSE %%if 0%%{?suse_version}
- Use for BuildRequires pkgconfig(SDL_net), pkgconfig(sdl)
  instead of libSDL_net-devel, SDL-devel
- Remove BuildRequires for pkgconfig
* Sat Oct  4 2014 nemysis@gmx.ch
- Change %%fdupes
* Mon Sep 29 2014 nemysis@gmx.ch
- Initial package creation
